﻿// GetShowRevisionMarkers_Setting.cs
//
// Copyright by Frank Schöneck, 2019

using System.IO;
using System.Xml;

public class MyClass
{
	[Start]
	public void MyFunction()
	{

		//Einstellung auslesen

		string node = "RevisionsMgt";
		string setting = "/Settings/CAT/MOD/Setting[@name='ShowRevisionMarkers']/Val";

		string settingTemp = GetProjectSetting(node, setting);

		new Decider().Decide(EnumDecisionType.eOkDecision,
			"Die Projekt Einstellung ist:\n\n" + settingTemp,
			"GetShowRevisionMarkers_Setting",
			EnumDecisionReturn.eOK,
			EnumDecisionReturn.eOK,
			"",
			false,
			EnumDecisionIcon.eINFORMATION);

		return;
	} //MyFunction

	/// Liest Projekt-Einstellung aus
	/// <param name="node">´'name'-attribute value of the MOD element to export</param>
	/// <param name="setting">Path of the setting to read</param>
	/// <returns>value of the setting as string</returns>
	public string GetProjectSetting(string node, string setting)
	{
		try
		{
			string projectPath = PathMap.SubstitutePath("$(PROJECTPATH)");
			string settingsTempFile = Path.Combine(System.Environment.GetEnvironmentVariable("TEMP"), "GetProjectSetting_temp.xml");
			new CommandLineInterpreter().Execute("XSettingsExport /XmlFile:\"" + settingsTempFile + "\" /prj:\"" + projectPath + "\" /Node:" + node);

			var xmlDocument = new XmlDocument();
			xmlDocument.Load(settingsTempFile);

			var settingNode = xmlDocument.DocumentElement.SelectSingleNode(setting);

			var projectSetting = settingNode.InnerText;

			File.Delete(settingsTempFile);
			return projectSetting;
		}
		catch (BaseException exc)
		{
			string strMessage = exc.Message;
			new Decider().Decide(EnumDecisionType.eOkDecision,
				"Exception: " + strMessage,
				"GetShowRevisionMarkers_Setting",
				EnumDecisionReturn.eOK,
				EnumDecisionReturn.eOK,
				"",
				false,
				EnumDecisionIcon.eFATALERROR);

			return string.Empty;
		}
	}
}
